{
  inputs,
  config,
  pkgs,
  ...
}:
{
  imports = [
    ../_base
    ./hardware-configuration.nix
    ./hardware-configuration.override.nix

    ../../modules/sddm.nix
    ../../modules/hyprland.nix
    ../../modules/hyprpaper.nix

    ../../modules/bash.nix
    ../../modules/kitty.nix
    ../../modules/git.nix
    ../../modules/direnv.nix
    ../../modules/firefox.nix
    ../../modules/zen-browser.nix
    ../../modules/steam.nix
    ../../modules/nvim
    ../../modules/ags
    ../../modules/grayjay.nix
    ../../modules/signal.nix
  ];

  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  services.btrfs.autoScrub.enable = true;

  networking.hostName = "kalle-pc";
  networking.networkmanager.enable = true;

  time.timeZone = "Europe/Amsterdam";

  services.xserver = {
    enable = true;
    xkb.layout = "us";
  };

  services.gvfs.enable = true;
  # Allow flashing ZSA keyboards
  hardware.keyboard.zsa.enable = true;
  # No need for firewall, since this machine is always at home
  networking.firewall.enable = false;

  # ROCm support
  hardware.graphics.extraPackages = with pkgs; [
    rocmPackages.clr.icd
  ];

  hyprland =
    let
      mod = "SUPER";
      uwsm = "${pkgs.uwsm}/bin/uwsm";
      mkUwsmApp = pkg: name: "${uwsm} app -- ${pkg}/share/applications/${name}.desktop";
    in
    {
      mod = mod;
      primaryMonitor = "DP-2";
      monitors = [
        {
          name = "DP-2";
          width = 1920;
          height = 1080;
          refreshRate = 144;
          x = 1080;
          y = 420;
          vrr = 1;
        }

        {
          name = "HDMI-A-2";
          width = 1920;
          height = 1080;
          x = 0;
          y = 0;
          transform = 3;
        }

        {
          name = "HDMI-A-1";
          width = 1920;
          height = 1080;
          x = 1080 + 1920;
          y = 0;
          transform = 1;
        }
      ];

      autoStart = [
        "uwsm-app -- ags run"
        (mkUwsmApp inputs.zen-browser.packages.x86_64-linux.default "zen")
        (mkUwsmApp pkgs.discord "discord")
      ];

      binds = {
        "${mod}, return" = "exec, ${mkUwsmApp pkgs.kitty "kitty"}";
        "${mod}, E" = "exec, ${pkgs.ulauncher}/bin/ulauncher-toggle #wofi --show drun";
        "${mod}, Print" = "exec, ${pkgs.bash}/bin/bash -c \"grim -g \\\"$(slurp)\\\" - | wl-copy\"";
        # Clipboard history
        # bind = $mainMod, V, exec, cliphist list | wofi --dmenu | cliphist decode | wl-copy
      };

      sensitivity = 0.1;

      layerRules = {
        "gtk-layer-shell" = [
          "blur"
          "ignorezero"
        ];
        "notifications2" = [
          "noanim"
          "blur"
          "ignorezero"
        ];
      };

      windowRules = {
        # ULauncher
        "class:^(ulauncher)$" = [
          "dimaround"
        ];
        # Auto workspace
        "class:zen" = [ "workspace 1 silent" ];
        "class:discord" = [ "workspace name:HDMI-A-1" ];
      };

    };
  hyprpaper.wallpaperFolder = "/home/kalle/Pictures/Wallpapers";

  home-manager.users.kalle = {
    home.packages = with pkgs; [
      discord
      discord-canary
      vesktop
      chromium
      httpie
      kdePackages.kate
      kdePackages.dolphin
      kdePackages.ark
      kdePackages.filelight
      rustup
      gcc
      prismlauncher
      pavucontrol
      difftastic
      sops
      unzip
      vlc
      feishin
      cachix
      torzu
      jq
      podman
    ];
  };

  # NOTE: For debugging staging server configs
  networking.extraHosts = ''
    192.168.10.99 staging.kallestruik.nl
    192.168.10.99 service1.staging.kallestruik.nl
    192.168.10.99 service2.staging.kallestruik.nl
    192.168.10.99 service3.staging.kallestruik.nl
    192.168.10.99 service4.staging.kallestruik.nl
    192.168.10.99 service5.staging.kallestruik.nl
    192.168.10.99 service6.staging.kallestruik.nl
  '';

  services.udev.packages = [
    # Allow flashing android devices and using ADB
    pkgs.android-udev-rules
  ];

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It's perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "23.05"; # Did you read the comment?
  # This value determines the Home Manager release that your configuration is
  # compatible with. This helps avoid breakage when a new Home Manager release
  # introduces backwards incompatible changes.
  #
  # You should not change this value, even if you update Home Manager. If you do
  # want to update the value, then make sure to first check the Home Manager
  # release notes.
  home-manager.users.kalle.home.stateVersion = "23.05"; # Please read the comment before changing.
}
